summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorSascha Hauer <s.hauer@pengutronix.de>2014-07-04 17:27:06 +0200
committerSascha Hauer <s.hauer@pengutronix.de>2014-07-04 17:27:06 +0200
commitefa4d684d8927428d333f841e37adeedcfe61cfb (patch)
tree5c780a94fdfa9557da018a485d7fe884244aaf48 /scripts
parent45d593bc5ec78e26e3a967517ed7a51f27c8b91f (diff)
parent10d63913999fbd5c02a2a8daecf877c24663bdca (diff)
downloadbarebox-efa4d684d8927428d333f841e37adeedcfe61cfb.tar.gz
barebox-efa4d684d8927428d333f841e37adeedcfe61cfb.tar.xz
Merge branch 'for-next/misc'
Conflicts: arch/arm/boards/chumby_falconwing/falconwing.c arch/arm/boards/imx233-olinuxino/imx23-olinuxino.c arch/x86/mach-x86.dox scripts/setupmbr/setupmbr.c
Diffstat (limited to 'scripts')
-rw-r--r--scripts/setupmbr/setupmbr.c16
-rw-r--r--scripts/tegra/.gitignore1
2 files changed, 9 insertions, 8 deletions
diff --git a/scripts/tegra/.gitignore b/scripts/tegra/.gitignore
new file mode 100644
index 0000000000..5d5891b243
--- /dev/null
+++ b/scripts/tegra/.gitignore
@@ -0,0 +1 @@
+cbootimage
diff --git a/scripts/setupmbr/setupmbr.c b/scripts/setupmbr/setupmbr.c
index f1dfd5fde9..1487498f1f 100644
--- a/scripts/setupmbr/setupmbr.c
+++ b/scripts/setupmbr/setupmbr.c
@@ -140,7 +140,7 @@ static void invalidate_daps(struct DAPS *sector)
* Create the indirect sector with the DAPS entries
* @param daps_table Where to store the entries
* @param size Size of the whole image in bytes
* @param pers_sector_count Count of sectors to skip after MBR for the persistant environment storage
* @return 0 on success
*
* This routine calculates the DAPS entries for the case the whole
@@ -326,10 +326,10 @@ static int check_for_space(const void *hd_image, off_t size)
}
/**
* Setup the persistant environment storage information
* @param patch_area Where to patch
* @param pers_sector_start Start sector of the persistant environment storage
* @param pers_sector_count Count of sectors for the persistant environment storage
* @return 0 on success
*/
static int store_pers_env_info(void *patch_area, uint64_t pers_sector_start, long pers_sector_count)
@@ -355,7 +355,7 @@ static int store_pers_env_info(void *patch_area, uint64_t pers_sector_start, lon
* Prepare the MBR and indirect sector for runtime
* @param fd_barebox barebox image to use
* @param fd_hd Hard disk image to prepare
* @param pers_sector_count Count of sectors to skip after MBR for the persistant environment storage
* @return 0 on success
*
* This routine expects a prepared hard disk image file with a partition table
@@ -390,7 +390,7 @@ static int barebox_overlay_mbr(int fd_barebox, int fd_hd, long pers_sector_count
}
/*
* the persistant environment storage is in front of the main
* barebox image. To handle both, we need more space in front of the
* the first partition.
*/
@@ -415,7 +415,7 @@ static int barebox_overlay_mbr(int fd_barebox, int fd_hd, long pers_sector_count
/*
* embed the barebox main image into the disk drive image,
* but keep the persistant environment storage untouched
* (if defined), e.g. store the main image behind this special area.
*/
memcpy(hd_image + ((pers_sector_count + 1) * SECTOR_SIZE),
@@ -471,7 +471,7 @@ static void print_usage(const char *pname)
{
printf("%s: Preparing a hard disk image for boot with barebox on x86.\n", pname);
printf("Usage is\n %s [options] -m <barebox image> -d <hd image>\n", pname);
- printf(" [options] are:\n -s <count> sector count of the persistant environment storage\n");
+ printf(" [options] are:\n -s <count> sector count of the persistent environment storage\n");
printf(" <barebox image> barebox's boot image file\n");
printf(" <hd image> HD image to store the barebox image\n");
printf(" If no '-s <x>' was given, barebox occupies sectors 0 to n, else sector 0 and x+1 to n\n");
@@ -140,7 +140,7 @@ static void invalidate_daps(struct DAPS *sector)
* @param daps_table Where to store the entries
* @param size Size of the whole image in bytes
- * @param pers_sector_count Count of sectors to skip after MBR for the persistant environment storage
+ * @param pers_sector_count Count of sectors to skip after MBR for the persistent environment storage
* @return 0 on success
*
@@ -326,10 +326,10 @@ static int check_for_space(const void *hd_image, off_t size)
}
/**
- * Setup the persistant environment storage information
+ * Setup the persistent environment storage information
* @param patch_area Where to patch
@@ -326,10 +326,10 @@ static int check_for_space(const void *hd_image, off_t size)
* @param patch_area Where to patch
- * @param pers_sector_start Start sector of the persistant environment storage
- * @param pers_sector_count Count of sectors for the persistant environment storage
+ * @param pers_sector_start Start sector of the persistent environment storage
+ * @param pers_sector_count Count of sectors for the persistent environment storage
* @return 0 on success
*/
@@ -355,7 +355,7 @@ static int store_pers_env_info(void *patch_area, uint64_t pers_sector_start, lon
* @param fd_barebox barebox image to use
* @param fd_hd Hard disk image to prepare
- * @param pers_sector_count Count of sectors to skip after MBR for the persistant environment storage
+ * @param pers_sector_count Count of sectors to skip after MBR for the persistent environment storage
* @return 0 on success
*
@@ -390,7 +390,7 @@ static int barebox_overlay_mbr(int fd_barebox, int fd_hd, long pers_sector_count
}
/*
- * the persistant environment storage is in front of the main
+ * the persistent environment storage is in front of the main
* barebox image. To handle both, we need more space in front of the
* the first partition.
@@ -415,7 +415,7 @@ static int barebox_overlay_mbr(int fd_barebox, int fd_hd, long pers_sector_count
/*
* embed the barebox main image into the disk drive image,
- * but keep the persistant environment storage untouched
+ * but keep the persistent environment storage untouched
* (if defined), e.g. store the main image behind this special area.
*/